==> apper-0.7.2.tar.bz2: apper-0.7.2/ApperKCM/TransactionModel.h <==
/***************************************************************************
 *   Copyright (C) 2009-2010 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef TRANSACTION_MODEL_H
#define TRANSACTION_MODEL_H

#include <QStandardItemModel>
#include <Transaction>

using namespace PackageKit;

namespace PackageKit {
    class Transaction;
}
class TransactionModel : public QStandardItemModel
{
Q_OBJECT

public:
    TransactionModel(QObject *parent = 0);

    void clear();

public slots:
    void addTransaction(PackageKit::Transaction *trans);

private:
    QString getDetailsLocalized(const QString &data) const;
    QString getTypeLine(const QStringList &lines, Transaction::Status status) const;

    QList<PackageKit::Transaction *> m_transactions;
};

#endif

==> apper_0.8.1.orig.tar.bz2: apper-0.8.1/ApperKCM/TransactionModel.h <==
/***************************************************************************
 *   Copyright (C) 2009-2010 by Daniel Nicoletti                           *
 *   dantti12@gmail.com                                                    *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef TRANSACTION_MODEL_H
#define TRANSACTION_MODEL_H

#include <QStandardItemModel>
#include <Transaction>

using namespace PackageKit;

namespace PackageKit {
    class Transaction;
}
class TransactionModel : public QStandardItemModel
{
Q_OBJECT

public:
    explicit TransactionModel(QObject *parent = 0);

    void clear();

public slots:
    void addTransaction(PackageKit::Transaction *trans);

private:
    QString getDetailsLocalized(const QString &data) const;
    QString getTypeLine(const QStringList &lines, Transaction::Status status) const;

    QList<PackageKit::Transaction *> m_transactions;
};

#endif
